
typedef unsigned char UBYTE;
typedef unsigned short USHORT;

enum Satellite {SAT_TERRA, SAT_AQUA, SAT_UNKNOWN};
enum {WATER, COAST, LAND};


/* pixel-level flags and values used internally by algorithm */
typedef struct {
	unsigned day		: 1;	/* daytime = 1, nighttime = 0 */
	unsigned potential_fire	: 1;	/* flag: potential fire pixel */
	unsigned high_range	: 1;	/* flag: using band 21 in place of 22 */
	unsigned missing_rad	: 1;	/* flag: missing radiance data */
	unsigned missing_geo	: 1;	/* flag: bad geolocation */
	unsigned surf		: 2;	/* surface type */
	unsigned cloud		: 1;	/* flag: cloudy pixel */
	unsigned process	: 1;	/* flag: apply detection algorithm
						to pixel */
	unsigned zsafe		: 1;	/* flag: include pixel when computing
						zone statistics */

	unsigned valid_bkg_pix	: 1;	/* flag: valid background pixel */
	unsigned bkg_fire	: 1;	/* flag: probable background-fire
						pixel */
	unsigned glint_level	: 2;	/* sun glint level (0-3) */
	} PixInfo;


typedef struct {
	float	L21[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	L22[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float	T21[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	T22[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	T31[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	T32[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float	R1[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	R2[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float	R7[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float32	lat[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float32	lon[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float	SolZenAng[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	SolAzAng[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	ViewZenAng[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float	ViewAzAng[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	uint8	landsea[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	/* used internally by algorithm */
	PixInfo	pixflags[LINES_PER_SCAN_1KM][SAMPLES_1KM];

	float32	LandMeanT21[SAMPLES_1KM], LandMeanDT[SAMPLES_1KM];
	uint16	LandZonePix[SAMPLES_1KM];
	float32	WaterMeanT21[SAMPLES_1KM], WaterMeanDT[SAMPLES_1KM];
	uint16	WaterZonePix[SAMPLES_1KM];
	} Scan;


typedef struct {
	float thresh_PF_T21[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	float thresh_PF_DT[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	} ScanThreshPF;


typedef struct {
	uint8   FireMask[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	uint8   ExtFireMask[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	uint32  FireQA[LINES_PER_SCAN_1KM][SAMPLES_1KM];
	} OutScan;



typedef struct{
	int32 NumPix;
  
	int32 NumMissingPix;
	int32 NumMissingRad;
	int32 NumMissingGeo;
	int32 NumLandPix;
	int32 NumFirePix;
	int32 NumLandFirePix;
	int32 NumWaterFirePix;

	int32 NumWaterPix;
	int32 NumCoastPix;
	int32 NumUnknownLandPix;
	int32 NumUnknownWaterPix;
	int32 NumNoFirePix;
	int32 NumGlintPix;
	int32 NumGlintRejectPix;
	int32 NumCoastRejectLandPix;
	int32 NumHotRejectPix;
	int32 NumClearingRejectPix;

	int32 NumCoastRejectWaterPix;

	int32 NumWaterAdjFirePix;
	int32 NumCloudAdjFirePix;

	int32 NumWaterCloudPix;
	int32 NumLandCloudPix;

	int32 NumDayPix;
	int32 NumNightPix;

	int32 NumGoodQuality;
	int32 NumOtherQuality;
	int32 NumNotProducedCloud;
	int32 NumNotProducedOther;
	} FireCounts;



